@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2017-2021 Contributors to the OpenSTF project <korte.termijn.prognoses@alliander.com> # noqa E501>
+# SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
 
@@ -217,10 +217,15 @@ def fides(data, all_forecasts=False):
     return forecast
 
 
-def main():
+def main(config=None, database=None):
     taskname = Path(__file__).name.replace(".py", "")
 
-    with TaskContext(taskname) as context:
+    if database is None or config is None:
+        raise RuntimeError(
+            "Please specifiy a configmanager and/or database connection object. These can be found in the openstef-dbc package."
+        )
+
+    with TaskContext(taskname, config, database) as context:
         context.logger.info("Querying wind prediction jobs from database")
         prediction_jobs = context.database.get_prediction_jobs_solar()
         num_prediction_jobs = len(prediction_jobs)
@@ -369,7 +374,7 @@ def apply_fit_insol(data, add_to_df=True, hours_delta=None, polynomial=False):
         return coefs[0] * values + coefs[1]
 
     def second_order_poly(coefs, values):
-        return coefs[0] * values ** 2 + coefs[1] * values + coefs[2]
+        return coefs[0] * values**2 + coefs[1] * values + coefs[2]
 
     # Define function to be minimized and subsequently minimize this function
     if polynomial:
