@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2017-2021 Contributors to the OpenSTF project <korte.termijn.prognoses@alliander.com> # noqa E501>
+# SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
 
@@ -25,7 +25,7 @@ Example:
 from datetime import datetime, timedelta
 from pathlib import Path
 
-from openstef_dbc.services.prediction_job import PredictionJobDataClass
+from openstef.data_classes.prediction_job import PredictionJobDataClass
 
 from openstef.enums import MLModelType
 from openstef.pipeline.train_model import train_model_pipeline
@@ -86,12 +86,18 @@ def train_model_task(
     context.perf_meter.checkpoint("Model trained")
 
 
-def main(model_type=None):
+def main(model_type=None, config=None, database=None):
+
+    if database is None or config is None:
+        raise RuntimeError(
+            "Please specifiy a configmanager and/or database connection object. These can be found in the openstef-dbc package."
+        )
+
     if model_type is None:
         model_type = [ml.value for ml in MLModelType]
 
     taskname = Path(__file__).name.replace(".py", "")
-    with TaskContext(taskname) as context:
+    with TaskContext(taskname, config, database) as context:
         PredictionJobLoop(context, model_type=model_type).map(train_model_task, context)
 
 
